// 权限辅助函数
export function hasPrivilege(privilege, required) {
  if (!privilege) return false;
  // lv-admin 拥有全部权限
  if (privilege.includes('lv-admin')) return true;
  const privArr = privilege.split(';').map(p => p.trim()).filter(Boolean);
  if (Array.isArray(required)) {
    return required.some(r => privArr.includes(r));
  }
  return privArr.includes(required);
}

// 合并永久权限和临时权限
export function mergePrivileges(permanentPrivilege, tempPrivilege) {
  if (!permanentPrivilege && !tempPrivilege) return '';
  
  let mergedPrivileges = [];
  
  // 添加永久权限
  if (permanentPrivilege) {
    mergedPrivileges.push(...permanentPrivilege.split(';').map(p => p.trim()).filter(Boolean));
  }
  
  // 添加临时权限（如果存在）
  if (tempPrivilege) {
    mergedPrivileges.push(...tempPrivilege.split(';').map(p => p.trim()).filter(Boolean));
  }
  
  // 去重并返回
  return [...new Set(mergedPrivileges)].join(';');
}

// 检查用户是否有指定权限（包括临时权限）
export function hasPrivilegeWithTemp(userData, required) {
  if (!userData) return false;
  
  // 合并永久权限和临时权限
  const mergedPrivileges = mergePrivileges(userData.privilege, userData.temp_privilege);
  
  return hasPrivilege(mergedPrivileges, required);
} 